@@ -114,7 +114,7 @@ EOF
     python3 -m venv ~/kolla-venv
     . ~/kolla-venv/bin/activate
 
-    pip install "${KOLLA_SRC_DIR}"
+    pip install "${KOLLA_SRC_DIR}" "requests<2.32"
 
     sudo ~/kolla-venv/bin/kolla-build
 
